=======================
foxtron-django-settings
=======================


.. image:: https://img.shields.io/pypi/v/foxtron_django_settings.svg
        :target: https://pypi.python.org/pypi/foxtron_django_settings

.. image:: https://img.shields.io/travis/samdolt/foxtron_django_settings.svg
        :target: https://travis-ci.com/samdolt/foxtron_django_settings

.. image:: https://readthedocs.org/projects/foxtron-django-settings/badge/?version=latest
        :target: https://foxtron-django-settings.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Tools used at Foxtron GmbH to simplify the writing of settings.py


* Free software: MIT license
* Documentation: https://foxtron-django-settings.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
